dbilib Library Documentation — dbilib - v0.4.1 Documentation

# dbilib Library Documentation

## Overview

The `dbilib` library is a mid-level CPython database interface project which is designed to fit between `sqlalchemy` and your database interface library.

The interface exposes methods for easily executing SQL statements and calling stored procedures - with minimal setup.

As of this release, the following database engines are supported:

- MySQL / MariaDB

- Oracle

- SQLite3

- SQL Server (coming soon)

If you have any questions that are not covered by this documentation, or if you spot any bugs, issues or have any recommendations, please feel free to contact us.

## Using the Library

This documentation suite contains detailed explanation and example usage for each of the library’s importable modules.

For detailed documentation, usage examples and links the source code itself, please refer to the Library API Documentation page.

If there is a specific module or method which you cannot find, a search field is built into the navigation bar to the left.

### Database Support

Our currently supported databases are listed in the Overview section on this page. However, for further detail regarding the databases supported by the SQLAlchemy library, please refer to their documentation, specifically their Included Dialects page, which lists the supported database dialects and their version(s).

### Connection Strings

For convenience, we have provided a link to the connection string (or database URL) templates for each database dialect supported by `sqlalchemy`. Generally, the database URLs follow this convention:

    dialect+driver://username:password@host:port/database

For example, the MySQL / MariaDB specific database URL using the `mysql-connector-python` driver, is:

    mysql+mysqlconnector://<user>:<pwd>@<host>:<port>/<database>

### Questions or Issues

If you have any issues or questions with your installation, please refer to the Troubleshooting section, or feel free to contact us.

## Troubleshooting

No guidance at this time.

## Documentation Contents

- Library API Documentation
- Change Log
- Contact Us

## Indices and Tables

- Index

- Module Index

Footnotes

Last updated: 27 Sep 2024